@@ -53,7 +53,7 @@ def quant(args):
     """
 
     # Main logger setup
-    main_log = logging.getLogger('py-tmt-quant')
+    main_log = logging.getLogger('pytmt')
     main_log.setLevel(logging.DEBUG)
 
     # create file handler which logs even debug messages
@@ -183,7 +183,8 @@ def quant(args):
                 spectrum = fraction_mzml.msdata.get(scan)
 
             except KeyError:
-                print('[error] spectrum index out of bound')
+                main_log.error('[error] spectrum index out of bound')
+                continue
 
             #except xml.etree.ElementTree.ParseError:
             #    if args.verbosity == 2:
